@@ -3,7 +3,7 @@ package Apache::Session::Store::NoSQL::Redis;
 use strict;
 use Redis;
 
-our $VERSION = '0.01';
+our $VERSION = '0.1';
 
 sub new {
     my ( $class, $session ) = @_;
@@ -24,7 +24,8 @@ sub insert {
 
 sub materialize {
     my ( $self, $session ) = @_;
-    $self->{cache}->get( $session->{data}->{_session_id} )
+    $session->{serialized} =
+      $self->{cache}->get( $session->{data}->{_session_id} )
       or die 'Object does not exist in data store.';
 }
 
@@ -44,10 +45,9 @@ Apache::Session::Store::NoSQL::Redis - An implementation of Apache::Session::Sto
 
 =head1 SYNOPSIS
 
- use Apache::Session::NoSQL;
+ use Apache::Session::Redis;
  
- tie %hash, 'Apache::Session::NoSQL', $id, {
-    Driver => 'Redis',
+ tie %hash, 'Apache::Session::Redis', $id, {
     # optional: default to localhost
     server => '127.0.0.1:6379',
  };
@@ -59,8 +59,18 @@ storage system
 
 =head1 AUTHOR
 
-This module was written by Xavier Guimard <x.guimard@free.fr>
+This module was written by Xavier Guimard E<lt>x.guimard@free.frE<gt>
 
 =head1 SEE ALSO
 
 L<Apache::Session::NoSQL>, L<Apache::Session>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2010 by Thomas Chemineau
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.10.0 or,
+at your option, any later version of Perl 5 you may have available.
+
+=cut
